@@ -45,6 +45,7 @@ pub async fn run(command: RunCommand) -> Result<(), CliError> {
                             print_intermediate_asm: command.print_intermediate_asm,
                             print_ir: command.print_ir,
                             binary_outfile: command.binary_outfile,
+                            debug_outfile: command.debug_outfile,
                             offline_mode: false,
                             silent_mode: command.silent_mode,
                         };
@@ -165,13 +166,15 @@ fn create_tx_with_script_and_data(
     outputs: Vec<fuel_tx::Output>,
 ) -> Transaction {
     let gas_price = 0;
-    let gas_limit = 10000000;
+    let gas_limit = fuel_tx::consts::MAX_GAS_PER_TX;
+    let byte_price = 0;
     let maturity = 0;
     let witnesses = vec![];
 
     Transaction::script(
         gas_price,
         gas_limit,
+        byte_price,
         maturity,
         script,
         script_data,
